@@ -25,11 +25,6 @@ import yaml
 from ansi2html import Ansi2HTMLConverter
 from dateutil import parser
 from docker.models.containers import Container
-from six import BytesIO
-from zuper_commons.fs import write_ustring_to_utf8_file
-from zuper_commons.text import box
-from zuper_commons.types import ZException
-
 from duckietown_challenges import __version__ as version_dc, ChallengesConstants, get_duckietown_server_url
 from duckietown_challenges.challenge import ChallengeDescription, EvaluationParameters
 from duckietown_challenges.challenge_results import (
@@ -53,11 +48,15 @@ from duckietown_challenges.rest_methods import (
     dtserver_job_heartbeat,
     dtserver_report_job,
     dtserver_work_submission,
-    get_challenge_description,
     SubmissionID,
 )
 from duckietown_challenges.utils import friendly_size, indent
 from duckietown_docker_utils.docker_run import get_developer_volumes
+from six import BytesIO
+from zuper_commons.fs import write_ustring_to_utf8_file
+from zuper_commons.text import box
+from zuper_commons.types import ZException
+
 from . import __version__, __version__ as version_dcr
 from .env_checks import (
     check_docker_environment,
@@ -130,6 +129,7 @@ Usage:
     parser.add_argument("--machine-id", default=None, help="Machine name")
     parser.add_argument("--name", default=None, help="Evaluator name")
     parser.add_argument("--impersonate", default=None)
+    parser.add_argument("--quota-cpu", type=float, default=None, help="average number of CPUs")
     DEFAULT_TMPDIR = "/tmp/duckietown/DT18/evaluator/executions"
 
     parser.add_argument("--tmpdir", default=DEFAULT_TMPDIR)
@@ -181,7 +181,7 @@ Usage:
     evaluator_name = (parsed.name or "noname") + "-" + "%s" % socket.gethostname() + "-" + "%s" % os.getpid()
     machine_id = parsed.machine_id or socket.gethostname()
     allow_host_network = False
-
+    quota_cpu = parsed.quota_cpu
     if token is None:
         token = get_token_from_shell_config()
 
@@ -212,6 +212,7 @@ Usage:
                     allow_host_network=allow_host_network,
                     use_ipfs=parsed.ipfs,
                     do_not_mess_with_repo=parsed.do_not_mess_with_repo,
+                    quota_cpu=quota_cpu,
                 )
                 multiplier = 1.0
                 if parsed.one:
@@ -270,6 +271,7 @@ Usage:
                     allow_host_network=allow_host_network,
                     use_ipfs=parsed.ipfs,
                     do_not_mess_with_repo=parsed.do_not_mess_with_repo,
+                    quota_cpu=quota_cpu,
                 )
             except NothingLeft as e:
                 if submission_id is None:
@@ -436,6 +438,7 @@ def go_(
     machine_id: str,
     tmpdir: str,
     copy_to_machine_cache: bool,
+    quota_cpu: Optional[float],
     token: str = None,
     impersonate: Optional[int] = None,
     debug_volumes: Optional[str] = None,
@@ -495,7 +498,8 @@ def go_(
     elogger.info(res=res)
 
     if False:
-        cd = get_challenge_description(token, res["challenge_name"], impersonate=impersonate)
+        pass
+        # cd = get_challenge_description(token, res["challenge_name"], impersonate=impersonate)
     else:
         cd = None
 
@@ -535,6 +539,7 @@ def go_(
         server_host=server_host,
         cd=cd,
         heartbeat=heartbeat,
+        quota_cpu=quota_cpu,
     )
 
     msg = "Reporting status %s for job %s submission %s.\n\n%s\n\n%s\n\n%s" % (
@@ -591,6 +596,7 @@ def get_cr(
     allow_host_network: bool,
     use_ipfs: bool,
     server_host: str,
+    quota_cpu: Optional[float],
     cd: Optional[ChallengeDescription],
     heartbeat: Optional[Callable] = None,
 ) -> Tuple[ChallengeResults, List]:
@@ -690,6 +696,7 @@ def get_cr(
                     server_host=server_host,
                     require_scores=require_scores,
                     heartbeat=heartbeat,
+                    quota_cpu=quota_cpu,
                 )
         finally:
             if do_upload:
@@ -762,6 +769,7 @@ def run_single(
     debug_volumes: Optional[str] = None,
     timeout_sec: float,
     require_scores: Set[str],
+    quota_cpu: Optional[float],
     allow_host_network: bool = False,
     use_ipfs: bool = False,
     heartbeat: Optional[Callable] = None,
@@ -781,6 +789,7 @@ def run_single(
     :param server_host:
     :param debug_volumes:
     :param timeout_sec:
+    :param quota_cpu:
     :param require_scores: Set of scores required for this step to be valid
     :param allow_host_network:
     :param use_ipfs:
@@ -859,6 +868,7 @@ def run_single(
             monitor=tomonitor[0],
             timeout_sec=timeout_sec,
             heartbeat=heartbeat,
+            quota_cpu=quota_cpu,
         )
 
         write_logs(wd, project, services=config["services"])
@@ -951,8 +961,21 @@ def run_one(
     monitor: ContainerName,
     services,
     timeout_sec: float,
+    quota_cpu: Optional[float],
     heartbeat: Optional[Callable] = None,
 ):
+    """
+
+    :param wd:
+    :param project:
+    :param do_pull:
+    :param monitor:
+    :param services:
+    :param timeout_sec:
+    :param quota_cpu: if it is not None, this is the avg number of cpus
+    :param heartbeat:
+    :return:
+    """
     client = check_docker_environment()
 
     # noinspection PyBroadException
@@ -1005,12 +1028,14 @@ def run_one(
             # cpu.cfs_period_us: the length of a period (in microseconds)
             # cpu.stat: exports throttling statistics [explained further below]
 
+            container.update(cpu_shares=250)
+
             if "solution" in service_name:
-                if False:
+                if quota_cpu is not None:
                     # every second
                     cpu_period = 1000 * 1000
-                    # get 100% cpu
-                    cpu_quota = 1000 * 1000
+                    # get 300% cpu
+                    cpu_quota = int(quota_cpu * 1000 * 1000)
 
                     container.update(cpu_period=cpu_period, cpu_quota=cpu_quota)
                     elogger.info(
@@ -1358,6 +1383,7 @@ class Tee:
     def close(self):
         if hasattr(self, "file"):
             if self.file is not None:
+                # noinspection PyUnresolvedReferences
                 self.file.close()
                 self.file = None
 
