@@ -65,9 +65,13 @@ def runner_local_main_(args: List[str] = None, token: str = None):
 
     group.add_argument("--challenge", default=None, help="override challenge")
     parser.add_argument("--debug-volumes", default=None)
+
+    parser.add_argument("--quota-cpu", type=float, default=None, help="average number of CPUs")
+
     group.add_argument("-C", dest="change", default=None)
 
     parsed = parser.parse_args(args=args)
+    quota_cpu = parsed.quota_cpu
 
     logger.debug("Running in directory %s" % os.getcwd())
 
@@ -259,6 +263,7 @@ For example, you could try:
             timeout_sec=step.timeout,
             server_host=server_host,
             require_scores=require_scores,
+            quota_cpu=quota_cpu,
         )
 
         fn = os.path.join(wd, "results.yaml")
@@ -267,15 +272,15 @@ For example, you could try:
             f.write(res)
 
         s = ""
-        s += "\nStatus: %s" % cr.status
+        s += f"\nStatus: {cr.status}"
         s += "\nScores:\n\n%s" % yaml.safe_dump(cr.scores, default_flow_style=False)
         s += "\n\n%s" % cr.msg
-        logger.info(indent(s, dark("step %s : " % challenge_step_name)))
+        logger.info(indent(s, dark(f"step {challenge_step_name} : ")))
 
         os.rename(wd, wd_final)
 
         if cr.status != SUCCESS:
-            logger.error('Breaking because step "%s" has result %s.' % (challenge_step_name, cr.status))
+            logger.error(f'Breaking because step "{challenge_step_name}" has result {cr.status}.')
             break
 
     outdir = os.path.realpath(output)
